/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 03088
 |           ALCOHOL AND DRUG SERVICES STUDY (ADSS), 1996-1999:
 |                            [UNITED STATES]
 |               (DATASET 0001: PHASE I FACILITY INTERVIEW)
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 03088-0001-statasetup.do)
 |
 **************************************************************************/

set mem 20m  /* Allocating 20 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Alcohol and Drug Services Study (ADSS), 1996-1999: [United States], Phase I Facility Interview"

#delimit ;
label define OUTCODE   1 "COMPLETE, NO PROBLEMS"
                       2 "COMPLETE, QUESTIONNAIRE COMPLETED LATER" ;
label define A_1       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define A_2       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_3       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define A_4A      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_4B      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_4C      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_5A      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_5B      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_5C      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_5D      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_5E      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_5F      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_5G      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_5H      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_5I      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_5J      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_5K      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_5L      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_5M      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_5N      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_5O      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_6       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "PRIVATE FOR-PROFIT ORGANIZATION"
                       2 "PRIVATE NON-PROFIT ORGANIZATION"
                       3 "CITY OR COUNTY GOVERNMENT AGENCY"
                       4 "STATE GOVERNMENT AGENCY"
                       5 "FEDERAL GOVERNMENT AGENCY" 6 "TRIBAL GOVERNMENT" ;
label define A_7A      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_7B      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_7C      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_7D      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_7E      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_7F      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_7G      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_7H      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_8       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_9BOX    -6 "DON'T KNOW" 1 "BOX CHECKED" 2 "BOX NOT CHECKED"
                       3 "BOX AND INFORMATION DO NOT AGREE"
                       4 "BOX NOT CHECKED BUT INFO GIVEN RE STAFF" ;
label define A_9A1     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9B1     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9C1     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9D1     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9E1     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9F1     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9G1     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9H1     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9I1     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9A2     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9B2     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9C2     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9D2     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9E2     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9F2     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9G2     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9H2     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9I2     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9A3     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9B3     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9C3     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9D3     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9E3     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9F3     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9G3     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9H3     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9I3     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9A4     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9B4     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9C4     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9D4     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9E4     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9F4     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9G4     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9H4     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_9I4     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A_10      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define A_11      -7 "NOT ASCERTAINED" 1 "YES" 2 "NO" ;
label define A_13A     -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_13B     -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_13C     -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_13D     -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_13E     -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_14A     -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_14B     -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_14C     -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_14D     -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_15A     -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_15B     -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_15C     -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_15D     -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_15E     -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_15F     -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_15G     -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_15H     -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_16      -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define A_17      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B1A1      -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define B1A2      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B1A3      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B1B1      -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define B1B2      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B1B3      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B1C1      -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define B1C2      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B1C3      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B1D1      -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define B1D2      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B1D3      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B1E1      -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define B1E2      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B1E3      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B1F1      -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define B1F2      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B1F3      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B1G1      -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define B1G2      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B1G3      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B1H1      -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define B1H2      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B1H3      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B1I1      -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define B1I2      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B1I3      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B1J2      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B1J3      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INT     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INA1    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INA2    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INA3    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INAT    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INB1    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INB2    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INB3    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INB4    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INB5    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INB6    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INBT    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INC1    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INC2    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INC3    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INC4    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INC5    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INC6    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INCT    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2IND1    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2IND2    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2IND3    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2IND4    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2IND5    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2IND6    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2IND7    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2IND8    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INDT    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INE1    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INE2    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INE3    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INE4    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INE5    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INE6    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INE7    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INE8    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INE9    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INE10   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2INET    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2RET     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REA1    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REA2    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REA3    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REAT    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REB1    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REB2    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REB3    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REB4    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REB5    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REB6    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REBT    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REC1    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REC2    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REC3    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REC4    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REC5    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REC6    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2RECT    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2RED1    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2RED2    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2RED3    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2RED4    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2RED5    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2RED6    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2RED7    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2RED8    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REDT    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REE1    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REE2    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REE3    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REE4    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REE5    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REE6    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REE7    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REE8    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REE9    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REE10   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2REET    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMT     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMA1    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMA2    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMA3    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMAT    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMB1    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMB2    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMB3    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMB4    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMB5    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMB6    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMBT    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMC1    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMC2    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMC3    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMC4    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMC5    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMC6    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMCT    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMD1    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMD2    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMD3    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMD4    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMD5    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMD6    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMD7    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMD8    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMDT    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OME1    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OME2    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OME3    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OME4    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OME5    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OME6    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OME7    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OME8    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OME9    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OME10   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OMET    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONT     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONA1    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONA2    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONA3    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONAT    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONB1    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONB2    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONB3    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONB4    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONB5    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONB6    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONBT    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONC1    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONC2    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONC3    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONC4    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONC5    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONC6    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONCT    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OND1    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OND2    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OND3    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OND4    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OND5    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OND6    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OND7    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2OND8    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONDT    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONE1    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONE2    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONE3    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONE4    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONE5    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONE6    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONE7    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONE8    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONE9    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONE10   -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B2ONET    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B3        -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B4        -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B5        -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B6A       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define B6B       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define B6C       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define B6D       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define B6E       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define B6F       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define B6G       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define B6H       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define B6I       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define B7A       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define B7B       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define B7C       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define B8        -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define B9        -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define B10A      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define B10B      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define B10C      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define B10D      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define B10E      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define B10F      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define B11       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B12A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B12B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B13       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B14       -9 "INAPPLICABLE" -6 "DON'T KNOW" ;
label define B15A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B15B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B15C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B15D      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B15E      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define B16       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "WITHIN 6 MONTHS" 2 "7 -12 MONTHS"
                       3 "13 -24 MONTHS" 4 "MORE THAN 24 MONTHS"
                       5 "UNLIMITED TIME ON METHADONE" ;
label define C1FMM     -7 "NOT ASCERTAINED" ;
label define C1FDD     -7 "NOT ASCERTAINED" ;
label define C1FYY     -7 "NOT ASCERTAINED" ;
label define C1TMM     -7 "NOT ASCERTAINED" ;
label define C1TDD     -7 "NOT ASCERTAINED" ;
label define C1TYY     -7 "NOT ASCERTAINED" ;
label define C2A1      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define C2A2      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define C2A3      -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define C2B1      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define C2B2      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define C2B3      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define C2C1      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define C2C2      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define C2C3      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define C2D1      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define C2D2      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define C2D3      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define C2E1      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define C2E2      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define C2E3      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define C2F1      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define C2F2      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define C3A       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define C3B       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NONE" ;
label define C3C       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NONE" ;
label define C3D       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NONE" ;
label define C4A       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define C4ANUM    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define C4B       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define C4BNUM    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define C4C       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define C4CNUM    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define C4D       -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW/CANT ASK IF CLIENTS HIV POS" 1 "YES"
                       2 "NO" ;
label define C4DNUM    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define C4E       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define C4ENUM    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define C5        -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define C6AA      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define C6AD      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define C6BA      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define C6BD      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define C7        -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define C8A       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NO ALCOHOL DETOX CLIENTS"
                       995 "995 DAYS AND OVER" ;
label define C8B       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NO COCAINE DETOX CLIENTS"
                       995 "995 DAYS AND OVER" ;
label define C8C       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NO HEROIN DETOX CLIENTS"
                       995 "995 DAYS AND OVER" ;
label define C9A       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define C9B       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define C9C       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define C9D       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define C9E       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define C9F       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define C9G       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define C9H       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define C9I       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define C9J       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define C9K       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define C9L       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define C9M       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define C9N       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define C9O       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define C9P       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define C9Q       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define C9R       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define C9S       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define D1        -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "YES" 2 "NO" ;
label define D2        -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 995 "995 ORGANIZATIONS OR MORE" ;
label define D3        -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 995 "995 CONTRACTS OR MORE" ;
label define D4        -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D5A       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define D5APC     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D5B       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define D5BPC     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D5C       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define D5CPC     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D5D       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define D5DPC     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D5DOTH    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "CONTRACT WITH COUNTY" 2 "PER DIEM"
                       3 "FEE PER ADMISSION, FEE FOR OUR PROGRAM"
                       4 "DEPT OF COMMUNITY CORRECTIONS" 5 "SELF PAYMENT"
                       6 "ARRANGED PAYMENT PLAN, NEGOTIATED"
                       7 "VERBAL AGREEMENTS" 8 "TIME SPEC PROG RATE"
                       9 "MANAGED CARE" 10 "PER HEAD, PER BED, PER DAY"
                       11 "DRG AMOUNT" 12 "COMBINATION OF ITEMS A. AND C."
                       13 "RE - EVALUATION AND EXTENSION" 14 "SLIDING SCALE"
                       15 "DISCOUNTED FEE FOR SERVICE" ;
label define D6A       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define D6B       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define D6C       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define D6D       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define D6E       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define D6F       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define D7        -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D8A       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D8APC     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D8B       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D8BPC     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D8C       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D8CPC     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D8D       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D8DPC     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D8E       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D8EPC     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D8F       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D8FPC     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D8G       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D8GPC     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D8H       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D8HPC     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D8I       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D8IPC     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D8J       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D8JPC     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D8TOT     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D9FMM     -7 "NOT ASCERTAINED" 88 "MULTIPLE TIME PERIODS GIVEN" ;
label define D9FDD     -7 "NOT ASCERTAINED" 88 "MULTIPLE TIME PERIODS GIVEN" ;
label define D9FYY     -7 "NOT ASCERTAINED" 88 "MULTIPLE TIME PERIODS GIVEN" ;
label define D9TMM     -7 "NOT ASCERTAINED" 88 "MULTIPLE TIME PERIODS GIVEN" ;
label define D9TDD     -7 "NOT ASCERTAINED" 88 "MULTIPLE TIME PERIODS GIVEN" ;
label define D9TYY     -7 "NOT ASCERTAINED" 88 "MULTIPLE TIME PERIODS GIVEN" ;
label define D10BOX    1 "BOX CHECKED" 2 "BOX NOT CHECKED"
                       3 "INFORMATION ABOUT SEVERAL LOCATIONS" ;
label define D10PC     -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define D11       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "AUDITED FINANCIAL STATEMENT FOR FACILITY"
                       2 "UNAUDITED FINANCIAL STATEMENT FOR FACILITY"
                       3 "ANNUAL BUDGET FOR FACILITY"
                       4 "FINANCIAL STATEMENT, BUDGET, OR RECORDS FROM ANOTHER FACILIT"
                       5 "ESTIMATED BASED ON RECORDS, BUDGETS, OR STATEMENTS"
                       6 "OTHER ESTIMATES" ;
label define D12A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D12APC    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D12B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D12BPC    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D12C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NO OUTPATIENT DOLLAR AMOUNT" ;
label define D12CPC    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NO OUTPATIENT PERCENT" ;
label define D12D      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D13A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D13APC    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "BAD DATA" ;
label define D13B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D13BPC    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" -5 "BAD DATA" ;
label define D13C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D14       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define D15A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D15APC    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D15B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D15BPC    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D15C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D15CPC    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D15D      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D16A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D16B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D16C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D16C1     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D16C2     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define D16D      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define D16E      -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define D17FMM    -7 "NOT ASCERTAINED" 88 "MULTIPLE TIME PERIODS GIVEN" ;
label define D17FDD    -7 "NOT ASCERTAINED" 88 "MULTIPLE TIME PERIODS GIVEN" ;
label define D17FYY    -7 "NOT ASCERTAINED" 88 "MULTIPLE TIME PERIODS GIVEN" ;
label define D17TMM    -7 "NOT ASCERTAINED" 88 "MULTIPLE TIME PERIODS GIVEN" ;
label define D17TDD    -7 "NOT ASCERTAINED" 88 "MULTIPLE TIME PERIODS GIVEN" ;
label define D17TYY    -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       88 "MULTIPLE TIME PERIODS GIVEN" ;
label define D18BOX    1 "BOX CHECKED" 2 "BOX NOT CHECKED"
                       3 "INFORMATION ABOUT SEVERAL LOCATIONS" ;
label define D18PC     -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define D19       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "AUDITED FINANCIAL STATEMENT FOR FAC ON L"
                       2 "UNAUDITED FINANCIAL STATEMENT FOR FAC ON"
                       3 "ANNUAL BUDGET FOR FAC ON LABEL"
                       4 "FINANCIAL STATEMENT, BUDGET OR RECORDS F"
                       5 "ESTIMATED BASED ON RECORDS, BUDGETS, OR"
                       6 "F. ER ESTIMATES" ;
label define D20       -7 "NOT ASCERTAINED" 1 "YES" 2 "NO"
                       3 "YES, BUT NO NAME GIVEN" ;
label define D21       1 "EXPLANATION PROVIDED HERE OR AS"
                       2 "NO COMMENTS GIVEN" ;
label define MULTSITE  0 "NOT A MULTI-SITE REPORTER"
                       1 "POSSIBLE MULTI -SITE REPORTER" ;
label define A_9FLG    1 "THERE IS A MISSING VALUE"
                       2 "THERE IS AN INCONSISTENCY"
                       3 "THERE IS NO MISSING VALUE OR INCONSISTEN" ;
label define B1FLG     1 "THERE IS A MISSING VALUE"
                       2 "THERE IS AN INCONSISTENCY"
                       3 "THERE IS NO MISSING VALUE OR INCONSISTEN" ;
label define B2FLG     1 "THERE IS A MISSING VALUE"
                       2 "THERE IS AN INCONSISTENCY"
                       3 "THERE IS NO MISSING VALUE OR INCONSISTEN" ;
label define B3FLG     1 "THERE IS A MISSING VALUE"
                       2 "THERE IS AN INCONSISTENCY"
                       3 "THERE IS NO MISSING VALUE OR INCONSISTEN" ;
label define B4FLG     1 "THERE IS A MISSING VALUE"
                       2 "THERE IS AN INCONSISTENCY"
                       3 "THERE IS NO MISSING VALUE OR INCONSISTEN" ;
label define B12FLG    1 "THERE IS A MISSING VALUE"
                       2 "THERE IS AN INCONSISTENCY"
                       3 "THERE IS NO MISSING VALUE OR INCONSISTEN" ;
label define D4FLG     1 "THERE IS A MISSING VALUE"
                       2 "THERE IS AN INCONSISTENCY"
                       3 "THERE IS NO MISSING VALUE OR INCONSISTEN" ;
label define C2FLG     1 "THERE IS A MISSING VALUE"
                       2 "THERE IS AN INCONSISTENCY"
                       3 "THERE IS NO MISSING VALUE OR INCONSISTEN" ;
label define C4AFLG    1 "THERE IS A MISSING VALUE"
                       2 "THERE IS AN INCONSISTENCY"
                       3 "THERE IS NO MISSING VALUE OR INCONSISTEN" ;
label define C4BFLG    1 "THERE IS A MISSING VALUE"
                       2 "THERE IS AN INCONSISTENCY"
                       3 "THERE IS NO MISSING VALUE OR INCONSISTEN" ;
label define D8FLG     1 "THERE IS A MISSING VALUE"
                       2 "THERE IS AN INCONSISTENCY"
                       3 "THERE IS NO MISSING VALUE OR INCONSISTEN" ;
label define D12FLG    1 "THERE IS A MISSING VALUE"
                       2 "THERE IS AN INCONSISTENCY"
                       3 "THERE IS NO MISSING VALUE OR INCONSISTEN" ;
label define D13FLG    1 "THERE IS A MISSING VALUE"
                       2 "THERE IS AN INCONSISTENCY"
                       3 "THERE IS NO MISSING VALUE OR INCONSISTEN" ;
label define D15FLG    1 "THERE IS A MISSING VALUE"
                       2 "THERE IS AN INCONSISTENCY"
                       3 "THERE IS NO MISSING VALUE OR INCONSISTEN" ;
label define D16FLG    1 "THERE IS A MISSING VALUE"
                       2 "THERE IS AN INCONSISTENCY"
                       3 "THERE IS NO MISSING VALUE OR INCONSISTEN" ;
label define A_9BOX_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9A1_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9B1_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9C1_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9D1_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9E1_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9F1_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9G1_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9H1_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9I1_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9A2_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9B2_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9C2_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9D2_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9E2_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9F2_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9G2_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9H2_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9I2_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9A3_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9B3_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9C3_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9D3_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9E3_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9F3_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9G3_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9H3_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9I3_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9A4_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9B4_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9C4_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9D4_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9E4_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9F4_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9G4_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9H4_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define A_9I4_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1A1_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1A2_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1A3_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1B1_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1B2_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1B3_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1C1_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1C2_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1C3_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1D1_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1D2_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1D3_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1E1_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1E2_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1E3_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1F1_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1F2_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1F3_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1G1_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1G2_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1G3_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1H1_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1H2_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1H3_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1I1_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1I2_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1I3_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1J2_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B1J3_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INT_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INA1_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INA2_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INA3_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INAT_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INB1_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INB2_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INB3_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INB4_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INB5_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INB6_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INBT_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INC1_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INC2_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INC3_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INC4_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INC5_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INC6_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INCT_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2IND1_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2IND2_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2IND3_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2IND4_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2IND5_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2IND6_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2IND7_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2IND8_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INDT_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INE1_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INE2_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INE3_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INE4_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INE5_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INE6_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INE7_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INE8_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INE9_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INE10F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2INET_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2RET_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REA1_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REA2_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REA3_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REAT_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REB1_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REB2_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REB3_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REB4_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REB5_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REB6_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REBT_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REC1_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REC2_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REC3_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REC4_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REC5_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REC6_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2RECT_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2RED1_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2RED2_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2RED3_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2RED4_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2RED5_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2RED6_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2RED7_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2RED8_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REDT_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REE1_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REE2_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REE3_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REE4_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REE5_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REE6_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REE7_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REE8_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REE9_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REE10F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2REET_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMT_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMA1_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMA2_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMA3_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMAT_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMB1_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMB2_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMB3_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMB4_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMB5_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMB6_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMBT_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMC1_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMC2_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMC3_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMC4_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMC5_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMC6_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMCT_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMD1_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMD2_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMD3_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMD4_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMD5_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMD6_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMD7_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMD8_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMDT_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OME1_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OME2_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OME3_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OME4_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OME5_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OME6_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OME7_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OME8_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OME9_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OME10F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OMET_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONT_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONA1_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONA2_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONA3_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONAT_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONB1_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONB2_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONB3_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONB4_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONB5_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONB6_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONBT_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONC1_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONC2_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONC3_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONC4_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONC5_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONC6_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONCT_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OND1_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OND2_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OND3_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OND4_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OND5_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OND6_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OND7_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2OND8_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONDT_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONE1_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONE2_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONE3_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONE4_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONE5_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONE6_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONE7_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONE8_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONE9_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONE10F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B2ONET_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B3_F      0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B4_F      0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B11_F     0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B12A_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B12B_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define B13_F     -9 "INAPPLICABLE" 0 "IMPUTED (SEE DEFS)" ;
label define B14_F     -9 "INAPPLICABLE" 0 "IMPUTED (SEE DEFS)" ;
label define B15A_F    -9 "INAPPLICABLE" 0 "IMPUTED (SEE DEFS)" ;
label define B15B_F    -9 "INAPPLICABLE" 0 "IMPUTED (SEE DEFS)" ;
label define B15C_F    -9 "INAPPLICABLE" 0 "IMPUTED (SEE DEFS)" ;
label define B15D_F    -9 "INAPPLICABLE" 0 "IMPUTED (SEE DEFS)" ;
label define B15E_F    -9 "INAPPLICABLE" 0 "IMPUTED (SEE DEFS)" ;
label define C2A1_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define C2B1_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define C2C1_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define C2D1_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define C2E1_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define C2F1_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define C4A_F     0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define C4ANUM_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define C4B_F     0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define C4BNUM_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D1_F      0 "NOT IMPUTED" ;
label define D4_F      0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D7_F      0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D8A_F     0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D8APC_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D8B_F     0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D8BPC_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D8C_F     0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D8CPC_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D8D_F     0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D8DPC_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D8E_F     0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D8EPC_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D8F_F     0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D8FPC_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D8G_F     0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D8GPC_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D8H_F     0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D8HPC_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D8I_F     0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D8IPC_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D8J_F     0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D8JPC_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D8TOT_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D12A_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D12APC_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D12B_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D12BPC_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D12C_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D12CPC_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D12D_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D13A_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D13APC_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D13B_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D13BPC_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D13C_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D14_F     0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D15A_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D15APC_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D15B_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D15BPC_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D15C_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D15CPC_F  0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D15D_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D16A_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D16B_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D16C_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D16C1_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D16C2_F   0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D16D_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define D16E_F    0 "NOT IMPUTED" 3 "IMPUTED (SEE DEFS)"
                       4 "IMPUTED (SEE DEFS)" 5 "IMPUTED (SEE DEFS)"
                       6 "IMPUTED (SEE DEFS)" 7 "IMPUTED (SEE DEFS)"
                       8 "IMPUTED (SEE DEFS)" 9 "IMPUTED (SEE DEFS)"
                       10 "IMPUTED (SEE DEFS)" 11 "IMPUTED (SEE DEFS)"
                       12 "IMPUTED (SEE DEFS)" 13 "IMPUTED (SEE DEFS)"
                       14 "IMPUTED (SEE DEFS)" ;
label define RATIOFLG  0 "NOT AN OUTLIER" 1 "OUTLIER" ;
label define QFSTRAT   1 "HOSPITAL INPATIENT ONLY"
                       2 "NON-HOSPITAL RESIDENTIAL ONLY"
                       3 "OUTPATIENT METHADONE ONLY"
                       4 "OUTPATIENT PREDOMINANTLY ALCOHOL" 5 "OUTPATIENT ER"
                       6 "COMBINED" ;
label define PSUTYPE2  1 "METRO CERTAINTY" 2 "METRO NONCERTAINTY"
                       3 "NONMETRO NONCERTAINTY" ;
label define CENREG    1 "NORTHEAST" 2 "MIDWEST" 3 "SOUTH" 4 "WEST" ;
label define TYPCARE5  1 "HOSPITAL INPATIENT ONLY"
                       2 "NON - HOSPITAL RESIDENTIAL ONLY"
                       3 "OUTPATIENT METHADONE ONLY"
                       4 "OUTPATIENT NON -METHADONE ONLY"
                       5 "COMBINATION FACILITIES" ;
label define SUPPSVC   1 "HIGH - OFFERED 5 TO 8 TYPES OF SUPPORT S"
                       2 "LOW - OFFERED 1 OR 2 TYPES OF SUPPORT SE"
                       3 "MEDIUM - OFFERED 3 OR 4 TYPES OF SUPPORT"
                       4 "NONE - OFFERED NO SUPPORT SERVICES" ;
label define TXSVC3    1 "HIGH - OFFERED 9 TO 11 TYPES OF TREATMEN"
                       2 "LOW - OFFERED 5 OR FEWER TYPES OF TREATM"
                       3 "MEDIUM - OFFERED 6 TO 8 TYPES OF TREATME" ;
label define BEALE     0 "CENTRAL COUNTIES, METRO AREA >=1 MIL"
                       1 "FRINGE COUNTIES, METRO AREA >= 1 MIL"
                       2 "COUNTIES IN METRO AREA, 250K TO 1 MIL"
                       3 "COUNTIES IN METRO AREA < 250K"
                       4 "URBAN POP >= 20K ADJACENT TO METRO AREA"
                       5 "URBAN POP >= 20K NOT ADJACENT TO METRO A"
                       6 "URBAN POP 2,500-19,999 ADJACENT TO METRO"
                       7 "URBAN POP 2,500-19,999 NOT ADJACENT TO M"
                       8 "RURAL OR < 2,500 URBAN POP ADJACENT TO M"
                       9 "RURAL OR < 2,500 URBAN POPULATION NOT AD" ;
label define BEAL_REC  1 "C = BEALE VALUE 4 OR 5" 2 "L = BEALE VALUE 0 OR 1"
                       3 "M = BEALE VALUE 2" 4 "R = BEALE VALUE 8 OR 9"
                       5 "S = BEALE VALUE 3" 6 "T = BEALE VALUE 6 OR 7" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace FACID = . if (FACID <= -1 )
replace OUTCODE = . if (OUTCODE <= -1 )
replace A_1 = . if (A_1 <= -1 )
replace A_2 = . if (A_2 <= -1 )
replace A_3 = . if (A_3 <= -1 )
replace A_4A = . if (A_4A <= -1 )
replace A_4B = . if (A_4B <= -1 )
replace A_4C = . if (A_4C <= -1 )
replace A_5A = . if (A_5A <= -1 )
replace A_5B = . if (A_5B <= -1 )
replace A_5C = . if (A_5C <= -1 )
replace A_5D = . if (A_5D <= -1 )
replace A_5E = . if (A_5E <= -1 )
replace A_5F = . if (A_5F <= -1 )
replace A_5G = . if (A_5G <= -1 )
replace A_5H = . if (A_5H <= -1 )
replace A_5I = . if (A_5I <= -1 )
replace A_5J = . if (A_5J <= -1 )
replace A_5K = . if (A_5K <= -1 )
replace A_5L = . if (A_5L <= -1 )
replace A_5M = . if (A_5M <= -1 )
replace A_5N = . if (A_5N <= -1 )
replace A_5O = . if (A_5O <= -1 )
replace A_6 = . if (A_6 <= -1 )
replace A_7A = . if (A_7A <= -1 )
replace A_7B = . if (A_7B <= -1 )
replace A_7C = . if (A_7C <= -1 )
replace A_7D = . if (A_7D <= -1 )
replace A_7E = . if (A_7E <= -1 )
replace A_7F = . if (A_7F <= -1 )
replace A_7G = . if (A_7G <= -1 )
replace A_7H = . if (A_7H <= -1 )
replace A_8 = . if (A_8 <= -1 )
replace A_9BOX = . if (A_9BOX <= -1 )
replace A_9A1 = . if (A_9A1 <= -1 )
replace A_9B1 = . if (A_9B1 <= -1 )
replace A_9C1 = . if (A_9C1 <= -1 )
replace A_9D1 = . if (A_9D1 <= -1 )
replace A_9E1 = . if (A_9E1 <= -1 )
replace A_9F1 = . if (A_9F1 <= -1 )
replace A_9G1 = . if (A_9G1 <= -1 )
replace A_9H1 = . if (A_9H1 <= -1 )
replace A_9I1 = . if (A_9I1 <= -1 )
replace A_9A2 = . if (A_9A2 <= -1 )
replace A_9B2 = . if (A_9B2 <= -1 )
replace A_9C2 = . if (A_9C2 <= -1 )
replace A_9D2 = . if (A_9D2 <= -1 )
replace A_9E2 = . if (A_9E2 <= -1 )
replace A_9F2 = . if (A_9F2 <= -1 )
replace A_9G2 = . if (A_9G2 <= -1 )
replace A_9H2 = . if (A_9H2 <= -1 )
replace A_9I2 = . if (A_9I2 <= -1 )
replace A_9A3 = . if (A_9A3 <= -1 )
replace A_9B3 = . if (A_9B3 <= -1 )
replace A_9C3 = . if (A_9C3 <= -1 )
replace A_9D3 = . if (A_9D3 <= -1 )
replace A_9E3 = . if (A_9E3 <= -1 )
replace A_9F3 = . if (A_9F3 <= -1 )
replace A_9G3 = . if (A_9G3 <= -1 )
replace A_9H3 = . if (A_9H3 <= -1 )
replace A_9I3 = . if (A_9I3 <= -1 )
replace A_9A4 = . if (A_9A4 <= -1 )
replace A_9B4 = . if (A_9B4 <= -1 )
replace A_9C4 = . if (A_9C4 <= -1 )
replace A_9D4 = . if (A_9D4 <= -1 )
replace A_9E4 = . if (A_9E4 <= -1 )
replace A_9F4 = . if (A_9F4 <= -1 )
replace A_9G4 = . if (A_9G4 <= -1 )
replace A_9H4 = . if (A_9H4 <= -1 )
replace A_9I4 = . if (A_9I4 <= -1 )
replace A_10 = . if (A_10 <= -1 )
replace A_11 = . if (A_11 <= -1 )
replace A_13A = . if (A_13A <= -1 )
replace A_13B = . if (A_13B <= -1 )
replace A_13C = . if (A_13C <= -1 )
replace A_13D = . if (A_13D <= -1 )
replace A_13E = . if (A_13E <= -1 )
replace A_14A = . if (A_14A <= -1 )
replace A_14B = . if (A_14B <= -1 )
replace A_14C = . if (A_14C <= -1 )
replace A_14D = . if (A_14D <= -1 )
replace A_15A = . if (A_15A <= -1 )
replace A_15B = . if (A_15B <= -1 )
replace A_15C = . if (A_15C <= -1 )
replace A_15D = . if (A_15D <= -1 )
replace A_15E = . if (A_15E <= -1 )
replace A_15F = . if (A_15F <= -1 )
replace A_15G = . if (A_15G <= -1 )
replace A_15H = . if (A_15H <= -1 )
replace A_16 = . if (A_16 <= -1 )
replace A_17 = . if (A_17 <= -1 )
replace B1A1 = . if (B1A1 <= -1 )
replace B1A2 = . if (B1A2 <= -1 )
replace B1A3 = . if (B1A3 <= -1 )
replace B1B1 = . if (B1B1 <= -1 )
replace B1B2 = . if (B1B2 <= -1 )
replace B1B3 = . if (B1B3 <= -1 )
replace B1C1 = . if (B1C1 <= -1 )
replace B1C2 = . if (B1C2 <= -1 )
replace B1C3 = . if (B1C3 <= -1 )
replace B1D1 = . if (B1D1 <= -1 )
replace B1D2 = . if (B1D2 <= -1 )
replace B1D3 = . if (B1D3 <= -1 )
replace B1E1 = . if (B1E1 <= -1 )
replace B1E2 = . if (B1E2 <= -1 )
replace B1E3 = . if (B1E3 <= -1 )
replace B1F1 = . if (B1F1 <= -1 )
replace B1F2 = . if (B1F2 <= -1 )
replace B1F3 = . if (B1F3 <= -1 )
replace B1G1 = . if (B1G1 <= -1 )
replace B1G2 = . if (B1G2 <= -1 )
replace B1G3 = . if (B1G3 <= -1 )
replace B1H1 = . if (B1H1 <= -1 )
replace B1H2 = . if (B1H2 <= -1 )
replace B1H3 = . if (B1H3 <= -1 )
replace B1I1 = . if (B1I1 <= -1 )
replace B1I2 = . if (B1I2 <= -1 )
replace B1I3 = . if (B1I3 <= -1 )
replace B1J2 = . if (B1J2 <= -1 )
replace B1J3 = . if (B1J3 <= -1 )
replace B2INT = . if (B2INT <= -1 )
replace B2INA1 = . if (B2INA1 <= -1 )
replace B2INA2 = . if (B2INA2 <= -1 )
replace B2INA3 = . if (B2INA3 <= -1 )
replace B2INAT = . if (B2INAT <= -1 )
replace B2INB1 = . if (B2INB1 <= -1 )
replace B2INB2 = . if (B2INB2 <= -1 )
replace B2INB3 = . if (B2INB3 <= -1 )
replace B2INB4 = . if (B2INB4 <= -1 )
replace B2INB5 = . if (B2INB5 <= -1 )
replace B2INB6 = . if (B2INB6 <= -1 )
replace B2INBT = . if (B2INBT <= -1 )
replace B2INC1 = . if (B2INC1 <= -1 )
replace B2INC2 = . if (B2INC2 <= -1 )
replace B2INC3 = . if (B2INC3 <= -1 )
replace B2INC4 = . if (B2INC4 <= -1 )
replace B2INC5 = . if (B2INC5 <= -1 )
replace B2INC6 = . if (B2INC6 <= -1 )
replace B2INCT = . if (B2INCT <= -1 )
replace B2IND1 = . if (B2IND1 <= -1 )
replace B2IND2 = . if (B2IND2 <= -1 )
replace B2IND3 = . if (B2IND3 <= -1 )
replace B2IND4 = . if (B2IND4 <= -1 )
replace B2IND5 = . if (B2IND5 <= -1 )
replace B2IND6 = . if (B2IND6 <= -1 )
replace B2IND7 = . if (B2IND7 <= -1 )
replace B2IND8 = . if (B2IND8 <= -1 )
replace B2INDT = . if (B2INDT <= -1 )
replace B2INE1 = . if (B2INE1 <= -1 )
replace B2INE2 = . if (B2INE2 <= -1 )
replace B2INE3 = . if (B2INE3 <= -1 )
replace B2INE4 = . if (B2INE4 <= -1 )
replace B2INE5 = . if (B2INE5 <= -1 )
replace B2INE6 = . if (B2INE6 <= -1 )
replace B2INE7 = . if (B2INE7 <= -1 )
replace B2INE8 = . if (B2INE8 <= -1 )
replace B2INE9 = . if (B2INE9 <= -1 )
replace B2INE10 = . if (B2INE10 <= -1 )
replace B2INET = . if (B2INET <= -1 )
replace B2RET = . if (B2RET <= -1 )
replace B2REA1 = . if (B2REA1 <= -1 )
replace B2REA2 = . if (B2REA2 <= -1 )
replace B2REA3 = . if (B2REA3 <= -1 )
replace B2REAT = . if (B2REAT <= -1 )
replace B2REB1 = . if (B2REB1 <= -1 )
replace B2REB2 = . if (B2REB2 <= -1 )
replace B2REB3 = . if (B2REB3 <= -1 )
replace B2REB4 = . if (B2REB4 <= -1 )
replace B2REB5 = . if (B2REB5 <= -1 )
replace B2REB6 = . if (B2REB6 <= -1 )
replace B2REBT = . if (B2REBT <= -1 )
replace B2REC1 = . if (B2REC1 <= -1 )
replace B2REC2 = . if (B2REC2 <= -1 )
replace B2REC3 = . if (B2REC3 <= -1 )
replace B2REC4 = . if (B2REC4 <= -1 )
replace B2REC5 = . if (B2REC5 <= -1 )
replace B2REC6 = . if (B2REC6 <= -1 )
replace B2RECT = . if (B2RECT <= -1 )
replace B2RED1 = . if (B2RED1 <= -1 )
replace B2RED2 = . if (B2RED2 <= -1 )
replace B2RED3 = . if (B2RED3 <= -1 )
replace B2RED4 = . if (B2RED4 <= -1 )
replace B2RED5 = . if (B2RED5 <= -1 )
replace B2RED6 = . if (B2RED6 <= -1 )
replace B2RED7 = . if (B2RED7 <= -1 )
replace B2RED8 = . if (B2RED8 <= -1 )
replace B2REDT = . if (B2REDT <= -1 )
replace B2REE1 = . if (B2REE1 <= -1 )
replace B2REE2 = . if (B2REE2 <= -1 )
replace B2REE3 = . if (B2REE3 <= -1 )
replace B2REE4 = . if (B2REE4 <= -1 )
replace B2REE5 = . if (B2REE5 <= -1 )
replace B2REE6 = . if (B2REE6 <= -1 )
replace B2REE7 = . if (B2REE7 <= -1 )
replace B2REE8 = . if (B2REE8 <= -1 )
replace B2REE9 = . if (B2REE9 <= -1 )
replace B2REE10 = . if (B2REE10 <= -1 )
replace B2REET = . if (B2REET <= -1 )
replace B2OMT = . if (B2OMT <= -1 )
replace B2OMA1 = . if (B2OMA1 <= -1 )
replace B2OMA2 = . if (B2OMA2 <= -1 )
replace B2OMA3 = . if (B2OMA3 <= -1 )
replace B2OMAT = . if (B2OMAT <= -1 )
replace B2OMB1 = . if (B2OMB1 <= -1 )
replace B2OMB2 = . if (B2OMB2 <= -1 )
replace B2OMB3 = . if (B2OMB3 <= -1 )
replace B2OMB4 = . if (B2OMB4 <= -1 )
replace B2OMB5 = . if (B2OMB5 <= -1 )
replace B2OMB6 = . if (B2OMB6 <= -1 )
replace B2OMBT = . if (B2OMBT <= -1 )
replace B2OMC1 = . if (B2OMC1 <= -1 )
replace B2OMC2 = . if (B2OMC2 <= -1 )
replace B2OMC3 = . if (B2OMC3 <= -1 )
replace B2OMC4 = . if (B2OMC4 <= -1 )
replace B2OMC5 = . if (B2OMC5 <= -1 )
replace B2OMC6 = . if (B2OMC6 <= -1 )
replace B2OMCT = . if (B2OMCT <= -1 )
replace B2OMD1 = . if (B2OMD1 <= -1 )
replace B2OMD2 = . if (B2OMD2 <= -1 )
replace B2OMD3 = . if (B2OMD3 <= -1 )
replace B2OMD4 = . if (B2OMD4 <= -1 )
replace B2OMD5 = . if (B2OMD5 <= -1 )
replace B2OMD6 = . if (B2OMD6 <= -1 )
replace B2OMD7 = . if (B2OMD7 <= -1 )
replace B2OMD8 = . if (B2OMD8 <= -1 )
replace B2OMDT = . if (B2OMDT <= -1 )
replace B2OME1 = . if (B2OME1 <= -1 )
replace B2OME2 = . if (B2OME2 <= -1 )
replace B2OME3 = . if (B2OME3 <= -1 )
replace B2OME4 = . if (B2OME4 <= -1 )
replace B2OME5 = . if (B2OME5 <= -1 )
replace B2OME6 = . if (B2OME6 <= -1 )
replace B2OME7 = . if (B2OME7 <= -1 )
replace B2OME8 = . if (B2OME8 <= -1 )
replace B2OME9 = . if (B2OME9 <= -1 )
replace B2OME10 = . if (B2OME10 <= -1 )
replace B2OMET = . if (B2OMET <= -1 )
replace B2ONT = . if (B2ONT <= -1 )
replace B2ONA1 = . if (B2ONA1 <= -1 )
replace B2ONA2 = . if (B2ONA2 <= -1 )
replace B2ONA3 = . if (B2ONA3 <= -1 )
replace B2ONAT = . if (B2ONAT <= -1 )
replace B2ONB1 = . if (B2ONB1 <= -1 )
replace B2ONB2 = . if (B2ONB2 <= -1 )
replace B2ONB3 = . if (B2ONB3 <= -1 )
replace B2ONB4 = . if (B2ONB4 <= -1 )
replace B2ONB5 = . if (B2ONB5 <= -1 )
replace B2ONB6 = . if (B2ONB6 <= -1 )
replace B2ONBT = . if (B2ONBT <= -1 )
replace B2ONC1 = . if (B2ONC1 <= -1 )
replace B2ONC2 = . if (B2ONC2 <= -1 )
replace B2ONC3 = . if (B2ONC3 <= -1 )
replace B2ONC4 = . if (B2ONC4 <= -1 )
replace B2ONC5 = . if (B2ONC5 <= -1 )
replace B2ONC6 = . if (B2ONC6 <= -1 )
replace B2ONCT = . if (B2ONCT <= -1 )
replace B2OND1 = . if (B2OND1 <= -1 )
replace B2OND2 = . if (B2OND2 <= -1 )
replace B2OND3 = . if (B2OND3 <= -1 )
replace B2OND4 = . if (B2OND4 <= -1 )
replace B2OND5 = . if (B2OND5 <= -1 )
replace B2OND6 = . if (B2OND6 <= -1 )
replace B2OND7 = . if (B2OND7 <= -1 )
replace B2OND8 = . if (B2OND8 <= -1 )
replace B2ONDT = . if (B2ONDT <= -1 )
replace B2ONE1 = . if (B2ONE1 <= -1 )
replace B2ONE2 = . if (B2ONE2 <= -1 )
replace B2ONE3 = . if (B2ONE3 <= -1 )
replace B2ONE4 = . if (B2ONE4 <= -1 )
replace B2ONE5 = . if (B2ONE5 <= -1 )
replace B2ONE6 = . if (B2ONE6 <= -1 )
replace B2ONE7 = . if (B2ONE7 <= -1 )
replace B2ONE8 = . if (B2ONE8 <= -1 )
replace B2ONE9 = . if (B2ONE9 <= -1 )
replace B2ONE10 = . if (B2ONE10 <= -1 )
replace B2ONET = . if (B2ONET <= -1 )
replace B3 = . if (B3 <= -1 )
replace B4 = . if (B4 <= -1 )
replace B5 = . if (B5 <= -1 )
replace B6A = . if (B6A <= -1 )
replace B6B = . if (B6B <= -1 )
replace B6C = . if (B6C <= -1 )
replace B6D = . if (B6D <= -1 )
replace B6E = . if (B6E <= -1 )
replace B6F = . if (B6F <= -1 )
replace B6G = . if (B6G <= -1 )
replace B6H = . if (B6H <= -1 )
replace B6I = . if (B6I <= -1 )
replace B7A = . if (B7A <= -1 )
replace B7B = . if (B7B <= -1 )
replace B7C = . if (B7C <= -1 )
replace B8 = . if (B8 <= -1 )
replace B9 = . if (B9 <= -1 )
replace B10A = . if (B10A <= -1 )
replace B10B = . if (B10B <= -1 )
replace B10C = . if (B10C <= -1 )
replace B10D = . if (B10D <= -1 )
replace B10E = . if (B10E <= -1 )
replace B10F = . if (B10F <= -1 )
replace B11 = . if (B11 <= -1 )
replace B12A = . if (B12A <= -1 )
replace B12B = . if (B12B <= -1 )
replace B13 = . if (B13 <= -1 )
replace B14 = . if (B14 <= -1 )
replace B15A = . if (B15A <= -1 )
replace B15B = . if (B15B <= -1 )
replace B15C = . if (B15C <= -1 )
replace B15D = . if (B15D <= -1 )
replace B15E = . if (B15E <= -1 )
replace B16 = . if (B16 <= -1 )
replace C1FMM = . if (C1FMM <= -1 )
replace C1FDD = . if (C1FDD <= -1 )
replace C1FYY = . if (C1FYY <= -1 )
replace C1TMM = . if (C1TMM <= -1 )
replace C1TDD = . if (C1TDD <= -1 )
replace C1TYY = . if (C1TYY <= -1 )
replace C2A1 = . if (C2A1 <= -1 )
replace C2A2 = . if (C2A2 <= -1 )
replace C2A3 = . if (C2A3 <= -1 )
replace C2B1 = . if (C2B1 <= -1 )
replace C2B2 = . if (C2B2 <= -1 )
replace C2B3 = . if (C2B3 <= -1 )
replace C2C1 = . if (C2C1 <= -1 )
replace C2C2 = . if (C2C2 <= -1 )
replace C2C3 = . if (C2C3 <= -1 )
replace C2D1 = . if (C2D1 <= -1 )
replace C2D2 = . if (C2D2 <= -1 )
replace C2D3 = . if (C2D3 <= -1 )
replace C2E1 = . if (C2E1 <= -1 )
replace C2E2 = . if (C2E2 <= -1 )
replace C2E3 = . if (C2E3 <= -1 )
replace C2F1 = . if (C2F1 <= -1 )
replace C2F2 = . if (C2F2 <= -1 )
replace C3A = . if (C3A <= -1 )
replace C3B = . if (C3B <= -1 )
replace C3C = . if (C3C <= -1 )
replace C3D = . if (C3D <= -1 )
replace C4A = . if (C4A <= -1 )
replace C4ANUM = . if (C4ANUM <= -1 )
replace C4B = . if (C4B <= -1 )
replace C4BNUM = . if (C4BNUM <= -1 )
replace C4C = . if (C4C <= -1 )
replace C4CNUM = . if (C4CNUM <= -1 )
replace C4D = . if (C4D <= -1 )
replace C4DNUM = . if (C4DNUM <= -1 )
replace C4E = . if (C4E <= -1 )
replace C4ENUM = . if (C4ENUM <= -1 )
replace C5 = . if (C5 <= -1 )
replace C6AA = . if (C6AA <= -1 )
replace C6AD = . if (C6AD <= -1 )
replace C6BA = . if (C6BA <= -1 )
replace C6BD = . if (C6BD <= -1 )
replace C7 = . if (C7 <= -1 )
replace C8A = . if (C8A <= -1 )
replace C8B = . if (C8B <= -1 )
replace C8C = . if (C8C <= -1 )
replace C9A = . if (C9A <= -1 )
replace C9B = . if (C9B <= -1 )
replace C9C = . if (C9C <= -1 )
replace C9D = . if (C9D <= -1 )
replace C9E = . if (C9E <= -1 )
replace C9F = . if (C9F <= -1 )
replace C9G = . if (C9G <= -1 )
replace C9H = . if (C9H <= -1 )
replace C9I = . if (C9I <= -1 )
replace C9J = . if (C9J <= -1 )
replace C9K = . if (C9K <= -1 )
replace C9L = . if (C9L <= -1 )
replace C9M = . if (C9M <= -1 )
replace C9N = . if (C9N <= -1 )
replace C9O = . if (C9O <= -1 )
replace C9P = . if (C9P <= -1 )
replace C9Q = . if (C9Q <= -1 )
replace C9R = . if (C9R <= -1 )
replace C9S = . if (C9S <= -1 )
replace D1 = . if (D1 <= -1 )
replace D2 = . if (D2 <= -1 )
replace D3 = . if (D3 <= -1 )
replace D4 = . if (D4 <= -1 )
replace D5A = . if (D5A <= -1 )
replace D5APC = . if (D5APC <= -1 )
replace D5B = . if (D5B <= -1 )
replace D5BPC = . if (D5BPC <= -1 )
replace D5C = . if (D5C <= -1 )
replace D5CPC = . if (D5CPC <= -1 )
replace D5D = . if (D5D <= -1 )
replace D5DPC = . if (D5DPC <= -1 )
replace D5DOTH = . if (D5DOTH <= -1 )
replace D6A = . if (D6A <= -1 )
replace D6B = . if (D6B <= -1 )
replace D6C = . if (D6C <= -1 )
replace D6D = . if (D6D <= -1 )
replace D6E = . if (D6E <= -1 )
replace D6F = . if (D6F <= -1 )
replace D7 = . if (D7 <= -1 )
replace D8A = . if (D8A <= -1 )
replace D8APC = . if (D8APC <= -1 )
replace D8B = . if (D8B <= -1 )
replace D8BPC = . if (D8BPC <= -1 )
replace D8C = . if (D8C <= -1 )
replace D8CPC = . if (D8CPC <= -1 )
replace D8D = . if (D8D <= -1 )
replace D8DPC = . if (D8DPC <= -1 )
replace D8E = . if (D8E <= -1 )
replace D8EPC = . if (D8EPC <= -1 )
replace D8F = . if (D8F <= -1 )
replace D8FPC = . if (D8FPC <= -1 )
replace D8G = . if (D8G <= -1 )
replace D8GPC = . if (D8GPC <= -1 )
replace D8H = . if (D8H <= -1 )
replace D8HPC = . if (D8HPC <= -1 )
replace D8I = . if (D8I <= -1 )
replace D8IPC = . if (D8IPC <= -1 )
replace D8J = . if (D8J <= -1 )
replace D8JPC = . if (D8JPC <= -1 )
replace D8TOT = . if (D8TOT <= -1 )
replace D9FMM = . if (D9FMM <= -1 )
replace D9FDD = . if (D9FDD <= -1 )
replace D9FYY = . if (D9FYY <= -1 )
replace D9TMM = . if (D9TMM <= -1 )
replace D9TDD = . if (D9TDD <= -1 )
replace D9TYY = . if (D9TYY <= -1 )
replace D10BOX = . if (D10BOX <= -1 )
replace D10PC = . if (D10PC <= -1 )
replace D11 = . if (D11 <= -1 )
replace D12A = . if (D12A <= -1 )
replace D12APC = . if (D12APC <= -1 )
replace D12B = . if (D12B <= -1 )
replace D12BPC = . if (D12BPC <= -1 )
replace D12C = . if (D12C <= -1 )
replace D12CPC = . if (D12CPC <= -1 )
replace D12D = . if (D12D <= -1 )
replace D13A = . if (D13A <= -1 )
replace D13APC = . if (D13APC <= -1 )
replace D13B = . if (D13B <= -1 )
replace D13BPC = . if (D13BPC <= -1 )
replace D13C = . if (D13C <= -1 )
replace D14 = . if (D14 <= -1 )
replace D15A = . if (D15A <= -1 )
replace D15APC = . if (D15APC <= -1 )
replace D15B = . if (D15B <= -1 )
replace D15BPC = . if (D15BPC <= -1 )
replace D15C = . if (D15C <= -1 )
replace D15CPC = . if (D15CPC <= -1 )
replace D15D = . if (D15D <= -1 )
replace D16A = . if (D16A <= -1 )
replace D16B = . if (D16B <= -1 )
replace D16C = . if (D16C <= -1 )
replace D16C1 = . if (D16C1 <= -1 )
replace D16C2 = . if (D16C2 <= -1 )
replace D16D = . if (D16D <= -1 )
replace D16E = . if (D16E <= -1 )
replace D17FMM = . if (D17FMM <= -1 )
replace D17FDD = . if (D17FDD <= -1 )
replace D17FYY = . if (D17FYY <= -1 )
replace D17TMM = . if (D17TMM <= -1 )
replace D17TDD = . if (D17TDD <= -1 )
replace D17TYY = . if (D17TYY <= -1 )
replace D18BOX = . if (D18BOX <= -1 )
replace D18PC = . if (D18PC <= -1 )
replace D19 = . if (D19 <= -1 )
replace D20 = . if (D20 <= -1 )
replace D21 = . if (D21 <= -1 )
replace MULTSITE = . if (MULTSITE <= -1 )
replace A_9FLG = . if (A_9FLG <= -1 )
replace B1FLG = . if (B1FLG <= -1 )
replace B2FLG = . if (B2FLG <= -1 )
replace B3FLG = . if (B3FLG <= -1 )
replace B4FLG = . if (B4FLG <= -1 )
replace B12FLG = . if (B12FLG <= -1 )
replace D4FLG = . if (D4FLG <= -1 )
replace C2FLG = . if (C2FLG <= -1 )
replace C4AFLG = . if (C4AFLG <= -1 )
replace C4BFLG = . if (C4BFLG <= -1 )
replace D8FLG = . if (D8FLG <= -1 )
replace D12FLG = . if (D12FLG <= -1 )
replace D13FLG = . if (D13FLG <= -1 )
replace D15FLG = . if (D15FLG <= -1 )
replace D16FLG = . if (D16FLG <= -1 )
replace A_9BOX_F = . if (A_9BOX_F <= -1 )
replace A_9A1_F = . if (A_9A1_F <= -1 )
replace A_9B1_F = . if (A_9B1_F <= -1 )
replace A_9C1_F = . if (A_9C1_F <= -1 )
replace A_9D1_F = . if (A_9D1_F <= -1 )
replace A_9E1_F = . if (A_9E1_F <= -1 )
replace A_9F1_F = . if (A_9F1_F <= -1 )
replace A_9G1_F = . if (A_9G1_F <= -1 )
replace A_9H1_F = . if (A_9H1_F <= -1 )
replace A_9I1_F = . if (A_9I1_F <= -1 )
replace A_9A2_F = . if (A_9A2_F <= -1 )
replace A_9B2_F = . if (A_9B2_F <= -1 )
replace A_9C2_F = . if (A_9C2_F <= -1 )
replace A_9D2_F = . if (A_9D2_F <= -1 )
replace A_9E2_F = . if (A_9E2_F <= -1 )
replace A_9F2_F = . if (A_9F2_F <= -1 )
replace A_9G2_F = . if (A_9G2_F <= -1 )
replace A_9H2_F = . if (A_9H2_F <= -1 )
replace A_9I2_F = . if (A_9I2_F <= -1 )
replace A_9A3_F = . if (A_9A3_F <= -1 )
replace A_9B3_F = . if (A_9B3_F <= -1 )
replace A_9C3_F = . if (A_9C3_F <= -1 )
replace A_9D3_F = . if (A_9D3_F <= -1 )
replace A_9E3_F = . if (A_9E3_F <= -1 )
replace A_9F3_F = . if (A_9F3_F <= -1 )
replace A_9G3_F = . if (A_9G3_F <= -1 )
replace A_9H3_F = . if (A_9H3_F <= -1 )
replace A_9I3_F = . if (A_9I3_F <= -1 )
replace A_9A4_F = . if (A_9A4_F <= -1 )
replace A_9B4_F = . if (A_9B4_F <= -1 )
replace A_9C4_F = . if (A_9C4_F <= -1 )
replace A_9D4_F = . if (A_9D4_F <= -1 )
replace A_9E4_F = . if (A_9E4_F <= -1 )
replace A_9F4_F = . if (A_9F4_F <= -1 )
replace A_9G4_F = . if (A_9G4_F <= -1 )
replace A_9H4_F = . if (A_9H4_F <= -1 )
replace A_9I4_F = . if (A_9I4_F <= -1 )
replace B1A1_F = . if (B1A1_F <= -1 )
replace B1A2_F = . if (B1A2_F <= -1 )
replace B1A3_F = . if (B1A3_F <= -1 )
replace B1B1_F = . if (B1B1_F <= -1 )
replace B1B2_F = . if (B1B2_F <= -1 )
replace B1B3_F = . if (B1B3_F <= -1 )
replace B1C1_F = . if (B1C1_F <= -1 )
replace B1C2_F = . if (B1C2_F <= -1 )
replace B1C3_F = . if (B1C3_F <= -1 )
replace B1D1_F = . if (B1D1_F <= -1 )
replace B1D2_F = . if (B1D2_F <= -1 )
replace B1D3_F = . if (B1D3_F <= -1 )
replace B1E1_F = . if (B1E1_F <= -1 )
replace B1E2_F = . if (B1E2_F <= -1 )
replace B1E3_F = . if (B1E3_F <= -1 )
replace B1F1_F = . if (B1F1_F <= -1 )
replace B1F2_F = . if (B1F2_F <= -1 )
replace B1F3_F = . if (B1F3_F <= -1 )
replace B1G1_F = . if (B1G1_F <= -1 )
replace B1G2_F = . if (B1G2_F <= -1 )
replace B1G3_F = . if (B1G3_F <= -1 )
replace B1H1_F = . if (B1H1_F <= -1 )
replace B1H2_F = . if (B1H2_F <= -1 )
replace B1H3_F = . if (B1H3_F <= -1 )
replace B1I1_F = . if (B1I1_F <= -1 )
replace B1I2_F = . if (B1I2_F <= -1 )
replace B1I3_F = . if (B1I3_F <= -1 )
replace B1J2_F = . if (B1J2_F <= -1 )
replace B1J3_F = . if (B1J3_F <= -1 )
replace B2INT_F = . if (B2INT_F <= -1 )
replace B2INA1_F = . if (B2INA1_F <= -1 )
replace B2INA2_F = . if (B2INA2_F <= -1 )
replace B2INA3_F = . if (B2INA3_F <= -1 )
replace B2INAT_F = . if (B2INAT_F <= -1 )
replace B2INB1_F = . if (B2INB1_F <= -1 )
replace B2INB2_F = . if (B2INB2_F <= -1 )
replace B2INB3_F = . if (B2INB3_F <= -1 )
replace B2INB4_F = . if (B2INB4_F <= -1 )
replace B2INB5_F = . if (B2INB5_F <= -1 )
replace B2INB6_F = . if (B2INB6_F <= -1 )
replace B2INBT_F = . if (B2INBT_F <= -1 )
replace B2INC1_F = . if (B2INC1_F <= -1 )
replace B2INC2_F = . if (B2INC2_F <= -1 )
replace B2INC3_F = . if (B2INC3_F <= -1 )
replace B2INC4_F = . if (B2INC4_F <= -1 )
replace B2INC5_F = . if (B2INC5_F <= -1 )
replace B2INC6_F = . if (B2INC6_F <= -1 )
replace B2INCT_F = . if (B2INCT_F <= -1 )
replace B2IND1_F = . if (B2IND1_F <= -1 )
replace B2IND2_F = . if (B2IND2_F <= -1 )
replace B2IND3_F = . if (B2IND3_F <= -1 )
replace B2IND4_F = . if (B2IND4_F <= -1 )
replace B2IND5_F = . if (B2IND5_F <= -1 )
replace B2IND6_F = . if (B2IND6_F <= -1 )
replace B2IND7_F = . if (B2IND7_F <= -1 )
replace B2IND8_F = . if (B2IND8_F <= -1 )
replace B2INDT_F = . if (B2INDT_F <= -1 )
replace B2INE1_F = . if (B2INE1_F <= -1 )
replace B2INE2_F = . if (B2INE2_F <= -1 )
replace B2INE3_F = . if (B2INE3_F <= -1 )
replace B2INE4_F = . if (B2INE4_F <= -1 )
replace B2INE5_F = . if (B2INE5_F <= -1 )
replace B2INE6_F = . if (B2INE6_F <= -1 )
replace B2INE7_F = . if (B2INE7_F <= -1 )
replace B2INE8_F = . if (B2INE8_F <= -1 )
replace B2INE9_F = . if (B2INE9_F <= -1 )
replace B2INE10F = . if (B2INE10F <= -1 )
replace B2INET_F = . if (B2INET_F <= -1 )
replace B2RET_F = . if (B2RET_F <= -1 )
replace B2REA1_F = . if (B2REA1_F <= -1 )
replace B2REA2_F = . if (B2REA2_F <= -1 )
replace B2REA3_F = . if (B2REA3_F <= -1 )
replace B2REAT_F = . if (B2REAT_F <= -1 )
replace B2REB1_F = . if (B2REB1_F <= -1 )
replace B2REB2_F = . if (B2REB2_F <= -1 )
replace B2REB3_F = . if (B2REB3_F <= -1 )
replace B2REB4_F = . if (B2REB4_F <= -1 )
replace B2REB5_F = . if (B2REB5_F <= -1 )
replace B2REB6_F = . if (B2REB6_F <= -1 )
replace B2REBT_F = . if (B2REBT_F <= -1 )
replace B2REC1_F = . if (B2REC1_F <= -1 )
replace B2REC2_F = . if (B2REC2_F <= -1 )
replace B2REC3_F = . if (B2REC3_F <= -1 )
replace B2REC4_F = . if (B2REC4_F <= -1 )
replace B2REC5_F = . if (B2REC5_F <= -1 )
replace B2REC6_F = . if (B2REC6_F <= -1 )
replace B2RECT_F = . if (B2RECT_F <= -1 )
replace B2RED1_F = . if (B2RED1_F <= -1 )
replace B2RED2_F = . if (B2RED2_F <= -1 )
replace B2RED3_F = . if (B2RED3_F <= -1 )
replace B2RED4_F = . if (B2RED4_F <= -1 )
replace B2RED5_F = . if (B2RED5_F <= -1 )
replace B2RED6_F = . if (B2RED6_F <= -1 )
replace B2RED7_F = . if (B2RED7_F <= -1 )
replace B2RED8_F = . if (B2RED8_F <= -1 )
replace B2REDT_F = . if (B2REDT_F <= -1 )
replace B2REE1_F = . if (B2REE1_F <= -1 )
replace B2REE2_F = . if (B2REE2_F <= -1 )
replace B2REE3_F = . if (B2REE3_F <= -1 )
replace B2REE4_F = . if (B2REE4_F <= -1 )
replace B2REE5_F = . if (B2REE5_F <= -1 )
replace B2REE6_F = . if (B2REE6_F <= -1 )
replace B2REE7_F = . if (B2REE7_F <= -1 )
replace B2REE8_F = . if (B2REE8_F <= -1 )
replace B2REE9_F = . if (B2REE9_F <= -1 )
replace B2REE10F = . if (B2REE10F <= -1 )
replace B2REET_F = . if (B2REET_F <= -1 )
replace B2OMT_F = . if (B2OMT_F <= -1 )
replace B2OMA1_F = . if (B2OMA1_F <= -1 )
replace B2OMA2_F = . if (B2OMA2_F <= -1 )
replace B2OMA3_F = . if (B2OMA3_F <= -1 )
replace B2OMAT_F = . if (B2OMAT_F <= -1 )
replace B2OMB1_F = . if (B2OMB1_F <= -1 )
replace B2OMB2_F = . if (B2OMB2_F <= -1 )
replace B2OMB3_F = . if (B2OMB3_F <= -1 )
replace B2OMB4_F = . if (B2OMB4_F <= -1 )
replace B2OMB5_F = . if (B2OMB5_F <= -1 )
replace B2OMB6_F = . if (B2OMB6_F <= -1 )
replace B2OMBT_F = . if (B2OMBT_F <= -1 )
replace B2OMC1_F = . if (B2OMC1_F <= -1 )
replace B2OMC2_F = . if (B2OMC2_F <= -1 )
replace B2OMC3_F = . if (B2OMC3_F <= -1 )
replace B2OMC4_F = . if (B2OMC4_F <= -1 )
replace B2OMC5_F = . if (B2OMC5_F <= -1 )
replace B2OMC6_F = . if (B2OMC6_F <= -1 )
replace B2OMCT_F = . if (B2OMCT_F <= -1 )
replace B2OMD1_F = . if (B2OMD1_F <= -1 )
replace B2OMD2_F = . if (B2OMD2_F <= -1 )
replace B2OMD3_F = . if (B2OMD3_F <= -1 )
replace B2OMD4_F = . if (B2OMD4_F <= -1 )
replace B2OMD5_F = . if (B2OMD5_F <= -1 )
replace B2OMD6_F = . if (B2OMD6_F <= -1 )
replace B2OMD7_F = . if (B2OMD7_F <= -1 )
replace B2OMD8_F = . if (B2OMD8_F <= -1 )
replace B2OMDT_F = . if (B2OMDT_F <= -1 )
replace B2OME1_F = . if (B2OME1_F <= -1 )
replace B2OME2_F = . if (B2OME2_F <= -1 )
replace B2OME3_F = . if (B2OME3_F <= -1 )
replace B2OME4_F = . if (B2OME4_F <= -1 )
replace B2OME5_F = . if (B2OME5_F <= -1 )
replace B2OME6_F = . if (B2OME6_F <= -1 )
replace B2OME7_F = . if (B2OME7_F <= -1 )
replace B2OME8_F = . if (B2OME8_F <= -1 )
replace B2OME9_F = . if (B2OME9_F <= -1 )
replace B2OME10F = . if (B2OME10F <= -1 )
replace B2OMET_F = . if (B2OMET_F <= -1 )
replace B2ONT_F = . if (B2ONT_F <= -1 )
replace B2ONA1_F = . if (B2ONA1_F <= -1 )
replace B2ONA2_F = . if (B2ONA2_F <= -1 )
replace B2ONA3_F = . if (B2ONA3_F <= -1 )
replace B2ONAT_F = . if (B2ONAT_F <= -1 )
replace B2ONB1_F = . if (B2ONB1_F <= -1 )
replace B2ONB2_F = . if (B2ONB2_F <= -1 )
replace B2ONB3_F = . if (B2ONB3_F <= -1 )
replace B2ONB4_F = . if (B2ONB4_F <= -1 )
replace B2ONB5_F = . if (B2ONB5_F <= -1 )
replace B2ONB6_F = . if (B2ONB6_F <= -1 )
replace B2ONBT_F = . if (B2ONBT_F <= -1 )
replace B2ONC1_F = . if (B2ONC1_F <= -1 )
replace B2ONC2_F = . if (B2ONC2_F <= -1 )
replace B2ONC3_F = . if (B2ONC3_F <= -1 )
replace B2ONC4_F = . if (B2ONC4_F <= -1 )
replace B2ONC5_F = . if (B2ONC5_F <= -1 )
replace B2ONC6_F = . if (B2ONC6_F <= -1 )
replace B2ONCT_F = . if (B2ONCT_F <= -1 )
replace B2OND1_F = . if (B2OND1_F <= -1 )
replace B2OND2_F = . if (B2OND2_F <= -1 )
replace B2OND3_F = . if (B2OND3_F <= -1 )
replace B2OND4_F = . if (B2OND4_F <= -1 )
replace B2OND5_F = . if (B2OND5_F <= -1 )
replace B2OND6_F = . if (B2OND6_F <= -1 )
replace B2OND7_F = . if (B2OND7_F <= -1 )
replace B2OND8_F = . if (B2OND8_F <= -1 )
replace B2ONDT_F = . if (B2ONDT_F <= -1 )
replace B2ONE1_F = . if (B2ONE1_F <= -1 )
replace B2ONE2_F = . if (B2ONE2_F <= -1 )
replace B2ONE3_F = . if (B2ONE3_F <= -1 )
replace B2ONE4_F = . if (B2ONE4_F <= -1 )
replace B2ONE5_F = . if (B2ONE5_F <= -1 )
replace B2ONE6_F = . if (B2ONE6_F <= -1 )
replace B2ONE7_F = . if (B2ONE7_F <= -1 )
replace B2ONE8_F = . if (B2ONE8_F <= -1 )
replace B2ONE9_F = . if (B2ONE9_F <= -1 )
replace B2ONE10F = . if (B2ONE10F <= -1 )
replace B2ONET_F = . if (B2ONET_F <= -1 )
replace B3_F = . if (B3_F <= -1 )
replace B4_F = . if (B4_F <= -1 )
replace B11_F = . if (B11_F <= -1 )
replace B12A_F = . if (B12A_F <= -1 )
replace B12B_F = . if (B12B_F <= -1 )
replace B13_F = . if (B13_F <= -1 )
replace B14_F = . if (B14_F <= -1 )
replace B15A_F = . if (B15A_F <= -1 )
replace B15B_F = . if (B15B_F <= -1 )
replace B15C_F = . if (B15C_F <= -1 )
replace B15D_F = . if (B15D_F <= -1 )
replace B15E_F = . if (B15E_F <= -1 )
replace C2A1_F = . if (C2A1_F <= -1 )
replace C2B1_F = . if (C2B1_F <= -1 )
replace C2C1_F = . if (C2C1_F <= -1 )
replace C2D1_F = . if (C2D1_F <= -1 )
replace C2E1_F = . if (C2E1_F <= -1 )
replace C2F1_F = . if (C2F1_F <= -1 )
replace C4A_F = . if (C4A_F <= -1 )
replace C4ANUM_F = . if (C4ANUM_F <= -1 )
replace C4B_F = . if (C4B_F <= -1 )
replace C4BNUM_F = . if (C4BNUM_F <= -1 )
replace D1_F = . if (D1_F <= -1 )
replace D4_F = . if (D4_F <= -1 )
replace D7_F = . if (D7_F <= -1 )
replace D8A_F = . if (D8A_F <= -1 )
replace D8APC_F = . if (D8APC_F <= -1 )
replace D8B_F = . if (D8B_F <= -1 )
replace D8BPC_F = . if (D8BPC_F <= -1 )
replace D8C_F = . if (D8C_F <= -1 )
replace D8CPC_F = . if (D8CPC_F <= -1 )
replace D8D_F = . if (D8D_F <= -1 )
replace D8DPC_F = . if (D8DPC_F <= -1 )
replace D8E_F = . if (D8E_F <= -1 )
replace D8EPC_F = . if (D8EPC_F <= -1 )
replace D8F_F = . if (D8F_F <= -1 )
replace D8FPC_F = . if (D8FPC_F <= -1 )
replace D8G_F = . if (D8G_F <= -1 )
replace D8GPC_F = . if (D8GPC_F <= -1 )
replace D8H_F = . if (D8H_F <= -1 )
replace D8HPC_F = . if (D8HPC_F <= -1 )
replace D8I_F = . if (D8I_F <= -1 )
replace D8IPC_F = . if (D8IPC_F <= -1 )
replace D8J_F = . if (D8J_F <= -1 )
replace D8JPC_F = . if (D8JPC_F <= -1 )
replace D8TOT_F = . if (D8TOT_F <= -1 )
replace D12A_F = . if (D12A_F <= -1 )
replace D12APC_F = . if (D12APC_F <= -1 )
replace D12B_F = . if (D12B_F <= -1 )
replace D12BPC_F = . if (D12BPC_F <= -1 )
replace D12C_F = . if (D12C_F <= -1 )
replace D12CPC_F = . if (D12CPC_F <= -1 )
replace D12D_F = . if (D12D_F <= -1 )
replace D13A_F = . if (D13A_F <= -1 )
replace D13APC_F = . if (D13APC_F <= -1 )
replace D13B_F = . if (D13B_F <= -1 )
replace D13BPC_F = . if (D13BPC_F <= -1 )
replace D13C_F = . if (D13C_F <= -1 )
replace D14_F = . if (D14_F <= -1 )
replace D15A_F = . if (D15A_F <= -1 )
replace D15APC_F = . if (D15APC_F <= -1 )
replace D15B_F = . if (D15B_F <= -1 )
replace D15BPC_F = . if (D15BPC_F <= -1 )
replace D15C_F = . if (D15C_F <= -1 )
replace D15CPC_F = . if (D15CPC_F <= -1 )
replace D15D_F = . if (D15D_F <= -1 )
replace D16A_F = . if (D16A_F <= -1 )
replace D16B_F = . if (D16B_F <= -1 )
replace D16C_F = . if (D16C_F <= -1 )
replace D16C1_F = . if (D16C1_F <= -1 )
replace D16C2_F = . if (D16C2_F <= -1 )
replace D16D_F = . if (D16D_F <= -1 )
replace D16E_F = . if (D16E_F <= -1 )
replace RATIOFLG = . if (RATIOFLG <= -1 )
replace QFSTRAT = . if (QFSTRAT <= -1 )
replace BUCLIENT = . if (BUCLIENT <= -1 )
replace PH1FW0 = . if (PH1FW0 <= -1.0000 )
replace VARSTRAT = . if (VARSTRAT <= -1 )
replace VARUNIT = . if (VARUNIT <= -1 )
replace PH1FW1 = . if (PH1FW1 <= -1.0000 )
replace PH1FW2 = . if (PH1FW2 <= -1.0000 )
replace PH1FW3 = . if (PH1FW3 <= -1.0000 )
replace PH1FW4 = . if (PH1FW4 <= -1.0000 )
replace PH1FW5 = . if (PH1FW5 <= -1.0000 )
replace PH1FW6 = . if (PH1FW6 <= -1.0000 )
replace PH1FW7 = . if (PH1FW7 <= -1.0000 )
replace PH1FW8 = . if (PH1FW8 <= -1.0000 )
replace PH1FW9 = . if (PH1FW9 <= -1.0000 )
replace PH1FW10 = . if (PH1FW10 <= -1.0000 )
replace PH1FW11 = . if (PH1FW11 <= -1.0000 )
replace PH1FW12 = . if (PH1FW12 <= -1.0000 )
replace PH1FW13 = . if (PH1FW13 <= -1.0000 )
replace PH1FW14 = . if (PH1FW14 <= -1.0000 )
replace PH1FW15 = . if (PH1FW15 <= -1.0000 )
replace PH1FW16 = . if (PH1FW16 <= -1.0000 )
replace PH1FW17 = . if (PH1FW17 <= -1.0000 )
replace PH1FW18 = . if (PH1FW18 <= -1.0000 )
replace PH1FW19 = . if (PH1FW19 <= -1.0000 )
replace PH1FW20 = . if (PH1FW20 <= -1.0000 )
replace PH1FW21 = . if (PH1FW21 <= -1.0000 )
replace PH1FW22 = . if (PH1FW22 <= -1.0000 )
replace PH1FW23 = . if (PH1FW23 <= -1.0000 )
replace PH1FW24 = . if (PH1FW24 <= -1.0000 )
replace PH1FW25 = . if (PH1FW25 <= -1.0000 )
replace PH1FW26 = . if (PH1FW26 <= -1.0000 )
replace PH1FW27 = . if (PH1FW27 <= -1.0000 )
replace PH1FW28 = . if (PH1FW28 <= -1.0000 )
replace PH1FW29 = . if (PH1FW29 <= -1.0000 )
replace PH1FW30 = . if (PH1FW30 <= -1.0000 )
replace PH1FW31 = . if (PH1FW31 <= -1.0000 )
replace PH1FW32 = . if (PH1FW32 <= -1.0000 )
replace PH1FW33 = . if (PH1FW33 <= -1.0000 )
replace PH1FW34 = . if (PH1FW34 <= -1.0000 )
replace PH1FW35 = . if (PH1FW35 <= -1.0000 )
replace PH1FW36 = . if (PH1FW36 <= -1.0000 )
replace PH1FW37 = . if (PH1FW37 <= -1.0000 )
replace PH1FW38 = . if (PH1FW38 <= -1.0000 )
replace PH1FW39 = . if (PH1FW39 <= -1.0000 )
replace PH1FW40 = . if (PH1FW40 <= -1.0000 )
replace PH1FW41 = . if (PH1FW41 <= -1.0000 )
replace PH1FW42 = . if (PH1FW42 <= -1.0000 )
replace PH1FW43 = . if (PH1FW43 <= -1.0000 )
replace PH1FW44 = . if (PH1FW44 <= -1.0000 )
replace PH1FW45 = . if (PH1FW45 <= -1.0000 )
replace PH1FW46 = . if (PH1FW46 <= -1.0000 )
replace PH1FW47 = . if (PH1FW47 <= -1.0000 )
replace PH1FW48 = . if (PH1FW48 <= -1.0000 )
replace PH1FW49 = . if (PH1FW49 <= -1.0000 )
replace PH1FW50 = . if (PH1FW50 <= -1.0000 )
replace PH1FW51 = . if (PH1FW51 <= -1.0000 )
replace PH1FW52 = . if (PH1FW52 <= -1.0000 )
replace PH1FW53 = . if (PH1FW53 <= -1.0000 )
replace PH1FW54 = . if (PH1FW54 <= -1.0000 )
replace PH1FW55 = . if (PH1FW55 <= -1.0000 )
replace PH1FW56 = . if (PH1FW56 <= -1.0000 )
replace PH1FW57 = . if (PH1FW57 <= -1.0000 )
replace PH1FW58 = . if (PH1FW58 <= -1.0000 )
replace PH1FW59 = . if (PH1FW59 <= -1.0000 )
replace PH1FW60 = . if (PH1FW60 <= -1.0000 )
replace PH1FW61 = . if (PH1FW61 <= -1.0000 )
replace PH1FW62 = . if (PH1FW62 <= -1.0000 )
replace PH1FW63 = . if (PH1FW63 <= -1.0000 )
replace PH1FW64 = . if (PH1FW64 <= -1.0000 )
replace PH1FW65 = . if (PH1FW65 <= -1.0000 )
replace PH1FW66 = . if (PH1FW66 <= -1.0000 )
replace PH1FW67 = . if (PH1FW67 <= -1.0000 )
replace PH1FW68 = . if (PH1FW68 <= -1.0000 )
replace PH1FW69 = . if (PH1FW69 <= -1.0000 )
replace PH1FW70 = . if (PH1FW70 <= -1.0000 )
replace PH1FW71 = . if (PH1FW71 <= -1.0000 )
replace PH1FW72 = . if (PH1FW72 <= -1.0000 )
replace PH1FW73 = . if (PH1FW73 <= -1.0000 )
replace PH1FW74 = . if (PH1FW74 <= -1.0000 )
replace PH1FW75 = . if (PH1FW75 <= -1.0000 )
replace PH1FW76 = . if (PH1FW76 <= -1.0000 )
replace PH1FW77 = . if (PH1FW77 <= -1.0000 )
replace PH1FW78 = . if (PH1FW78 <= -1.0000 )
replace PH1FW79 = . if (PH1FW79 <= -1.0000 )
replace PH1FW80 = . if (PH1FW80 <= -1.0000 )
replace PH1FW81 = . if (PH1FW81 <= -1.0000 )
replace PH1FW82 = . if (PH1FW82 <= -1.0000 )
replace PH1FW83 = . if (PH1FW83 <= -1.0000 )
replace PH1FW84 = . if (PH1FW84 <= -1.0000 )
replace PH1FW85 = . if (PH1FW85 <= -1.0000 )
replace PH1FW86 = . if (PH1FW86 <= -1.0000 )
replace PH1FW87 = . if (PH1FW87 <= -1.0000 )
replace PH1FW88 = . if (PH1FW88 <= -1.0000 )
replace PH1FW89 = . if (PH1FW89 <= -1.0000 )
replace PH1FW90 = . if (PH1FW90 <= -1.0000 )
replace PH1FW91 = . if (PH1FW91 <= -1.0000 )
replace PH1FW92 = . if (PH1FW92 <= -1.0000 )
replace PH1FW93 = . if (PH1FW93 <= -1.0000 )
replace PH1FW94 = . if (PH1FW94 <= -1.0000 )
replace PH1FW95 = . if (PH1FW95 <= -1.0000 )
replace PH1FW96 = . if (PH1FW96 <= -1.0000 )
replace PH1FW97 = . if (PH1FW97 <= -1.0000 )
replace PH1FW98 = . if (PH1FW98 <= -1.0000 )
replace PH1FW99 = . if (PH1FW99 <= -1.0000 )
replace PH1FW100 = . if (PH1FW100 <= -1.0000 )
replace PH1FW101 = . if (PH1FW101 <= -1.0000 )
replace PH1FW102 = . if (PH1FW102 <= -1.0000 )
replace PH1FW103 = . if (PH1FW103 <= -1.0000 )
replace PH1FW104 = . if (PH1FW104 <= -1.0000 )
replace PH1FW105 = . if (PH1FW105 <= -1.0000 )
replace PH1FW106 = . if (PH1FW106 <= -1.0000 )
replace PH1FW107 = . if (PH1FW107 <= -1.0000 )
replace PH1FW108 = . if (PH1FW108 <= -1.0000 )
replace PH1FW109 = . if (PH1FW109 <= -1.0000 )
replace PH1FW110 = . if (PH1FW110 <= -1.0000 )
replace PH1FW111 = . if (PH1FW111 <= -1.0000 )
replace PH1FW112 = . if (PH1FW112 <= -1.0000 )
replace PH1FW113 = . if (PH1FW113 <= -1.0000 )
replace PH1FW114 = . if (PH1FW114 <= -1.0000 )
replace PH1FW115 = . if (PH1FW115 <= -1.0000 )
replace PH1FW116 = . if (PH1FW116 <= -1.0000 )
replace PH1FW117 = . if (PH1FW117 <= -1.0000 )
replace PH1FW118 = . if (PH1FW118 <= -1.0000 )
replace PH1FW119 = . if (PH1FW119 <= -1.0000 )
replace PH1FW120 = . if (PH1FW120 <= -1.0000 )
replace PH1FW121 = . if (PH1FW121 <= -1.0000 )
replace PH1FW122 = . if (PH1FW122 <= -1.0000 )
replace PH1FW123 = . if (PH1FW123 <= -1.0000 )
replace PH1FW124 = . if (PH1FW124 <= -1.0000 )
replace PH1FW125 = . if (PH1FW125 <= -1.0000 )
replace PH1FW126 = . if (PH1FW126 <= -1.0000 )
replace PH1FW127 = . if (PH1FW127 <= -1.0000 )
replace PH1FW128 = . if (PH1FW128 <= -1.0000 )
replace PH1FW129 = . if (PH1FW129 <= -1.0000 )
replace PH1FW130 = . if (PH1FW130 <= -1.0000 )
replace PH1FW131 = . if (PH1FW131 <= -1.0000 )
replace PH1FW132 = . if (PH1FW132 <= -1.0000 )
replace PH1FW133 = . if (PH1FW133 <= -1.0000 )
replace PH1FW134 = . if (PH1FW134 <= -1.0000 )
replace PH1FW135 = . if (PH1FW135 <= -1.0000 )
replace PH1FW136 = . if (PH1FW136 <= -1.0000 )
replace PH1FW137 = . if (PH1FW137 <= -1.0000 )
replace PH1FW138 = . if (PH1FW138 <= -1.0000 )
replace PH1FW139 = . if (PH1FW139 <= -1.0000 )
replace PH1FW140 = . if (PH1FW140 <= -1.0000 )
replace PH1FW141 = . if (PH1FW141 <= -1.0000 )
replace PH1FW142 = . if (PH1FW142 <= -1.0000 )
replace PH1FW143 = . if (PH1FW143 <= -1.0000 )
replace PH1FW144 = . if (PH1FW144 <= -1.0000 )
replace PH1FW145 = . if (PH1FW145 <= -1.0000 )
replace PH1FW146 = . if (PH1FW146 <= -1.0000 )
replace PH1FW147 = . if (PH1FW147 <= -1.0000 )
replace PH1FW148 = . if (PH1FW148 <= -1.0000 )
replace PH1FW149 = . if (PH1FW149 <= -1.0000 )
replace PH1FW150 = . if (PH1FW150 <= -1.0000 )
replace PH1FW151 = . if (PH1FW151 <= -1.0000 )
replace PH1FW152 = . if (PH1FW152 <= -1.0000 )
replace PH1FW153 = . if (PH1FW153 <= -1.0000 )
replace PH1FW154 = . if (PH1FW154 <= -1.0000 )
replace PH1FW155 = . if (PH1FW155 <= -1.0000 )
replace PH1FW156 = . if (PH1FW156 <= -1.0000 )
replace PH1FW157 = . if (PH1FW157 <= -1.0000 )
replace PH1FW158 = . if (PH1FW158 <= -1.0000 )
replace PH1FW159 = . if (PH1FW159 <= -1.0000 )
replace PH1FW160 = . if (PH1FW160 <= -1.0000 )
replace PH1FW161 = . if (PH1FW161 <= -1.0000 )
replace PH1FW162 = . if (PH1FW162 <= -1.0000 )
replace PH1FW163 = . if (PH1FW163 <= -1.0000 )
replace PH1FW164 = . if (PH1FW164 <= -1.0000 )
replace PH1FW165 = . if (PH1FW165 <= -1.0000 )
replace PH1FW166 = . if (PH1FW166 <= -1.0000 )
replace PH1FW167 = . if (PH1FW167 <= -1.0000 )
replace PH1FW168 = . if (PH1FW168 <= -1.0000 )
replace PH1FW169 = . if (PH1FW169 <= -1.0000 )
replace PH1FW170 = . if (PH1FW170 <= -1.0000 )
replace PH1FW171 = . if (PH1FW171 <= -1.0000 )
replace PH1FW172 = . if (PH1FW172 <= -1.0000 )
replace PH1FW173 = . if (PH1FW173 <= -1.0000 )
replace PH1FW174 = . if (PH1FW174 <= -1.0000 )
replace PH1FW175 = . if (PH1FW175 <= -1.0000 )
replace PH1FW176 = . if (PH1FW176 <= -1.0000 )
replace PH1FW177 = . if (PH1FW177 <= -1.0000 )
replace PH1FW178 = . if (PH1FW178 <= -1.0000 )
replace PH1FW179 = . if (PH1FW179 <= -1.0000 )
replace PH1FW180 = . if (PH1FW180 <= -1.0000 )
replace PH1FW181 = . if (PH1FW181 <= -1.0000 )
replace PH1FW182 = . if (PH1FW182 <= -1.0000 )
replace PH1FW183 = . if (PH1FW183 <= -1.0000 )
replace PH1FW184 = . if (PH1FW184 <= -1.0000 )
replace PH1FW185 = . if (PH1FW185 <= -1.0000 )
replace PH1FW186 = . if (PH1FW186 <= -1.0000 )
replace PH1FW187 = . if (PH1FW187 <= -1.0000 )
replace PH1FW188 = . if (PH1FW188 <= -1.0000 )
replace PH1FW189 = . if (PH1FW189 <= -1.0000 )
replace PH1FW190 = . if (PH1FW190 <= -1.0000 )
replace PH1FW191 = . if (PH1FW191 <= -1.0000 )
replace PH1FW192 = . if (PH1FW192 <= -1.0000 )
replace PH1FW193 = . if (PH1FW193 <= -1.0000 )
replace PH1FW194 = . if (PH1FW194 <= -1.0000 )
replace PH1FW195 = . if (PH1FW195 <= -1.0000 )
replace PH1FW196 = . if (PH1FW196 <= -1.0000 )
replace PH1FW197 = . if (PH1FW197 <= -1.0000 )
replace PH1FW198 = . if (PH1FW198 <= -1.0000 )
replace PH1FW199 = . if (PH1FW199 <= -1.0000 )
replace PH1FW200 = . if (PH1FW200 <= -1.0000 )
replace STRATUM = . if (STRATUM <= -1 )
replace PSUTYPE2 = . if (PSUTYPE2 <= -1 )
replace CENREG = . if (CENREG <= -1 )
replace TOTCNT = . if (TOTCNT <= -1 )
replace SMPCNT = . if (SMPCNT <= -1 )
replace TYPCARE5 = . if (TYPCARE5 <= -1 )
replace SUPPSVC = . if (SUPPSVC <= -1 )
replace TXSVC3 = . if (TXSVC3 <= -1 )
replace BEALE = . if (BEALE <= -1 )
replace BEAL_REC = . if (BEAL_REC <= -1 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

